==> vue-milestone-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/milestone/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import Tooltip from "@dftvue2-opentiny/vue-tooltip";
import { iconYes } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    Tooltip,
    IconYes: iconYes()
  },
  props: [].concat(props, ["solid", "start", "lineStyle", "timeField", "showNumber", "flagBefore", "completedField", "milestonesStatus", "statusField", "nameField", "flagField", "flagNameField", "flagContentField", "flagStatusField", "data", "space"]),
  emits: ["click", "flagclick", "flag-click"],
  // deprecated 原事件flagclick v3.5.0废弃，v3.17.0移除；移除原因：命名规范
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-milestone"
  }, [_c("tooltip", {
    ref: "tooltip",
    attrs: {
      "type": "normal",
      "placement": "top",
      "content": _vm.state.tipContent
    }
  }), _vm._l(_vm.data, function(node, index) {
    return _c("div", {
      key: index,
      class: ["tiny-milestone__node", {
        "is-solid": _vm.solid
      }, "node-status-" + node[_vm.statusField]],
      style: {
        width: _vm.space ? _vm.space + "px" : 100 / _vm.data.length + "%"
      }
    }, [_vm._t("top", null, {
      "slotScope": node,
      "topSlotClass": "top-slot-class"
    }), _c("div", {
      staticClass: "tiny-milestone__icon tiny-milestone__icon-custom",
      class: [node[_vm.statusField] === _vm.completedField && !_vm.solid ? "is-completed" : "", "status-" + node[_vm.statusField]],
      style: _vm.getMileIcon(node),
      on: {
        "click": function click($event) {
          return _vm.handleClick({
            index,
            node
          });
        }
      }
    }, [_vm._t("icon", function() {
      return [node[_vm.statusField] === _vm.completedField ? _c("icon-yes", {
        staticClass: "tiny-svg-size"
      }) : _c("span", [_vm._v(_vm._s(_vm.showNumber ? index + _vm.start : ""))])];
    }, {
      "slotScope": node
    })], 2), _c("div", {
      class: ["tiny-milestone__line", {
        "tiny-milestone__line-end": index === _vm.data.length - 1,
        "tiny-milestone__line-completed-custom": node[_vm.statusField] === "completed"
      }],
      style: _vm.getLineColor(node[_vm.statusField])
    }, [index < _vm.data.length - 1 ? _c("div", _vm._l(_vm.getMileContent({
      data: _vm.data,
      index
    }), function(flag, idx) {
      return _c("div", {
        key: idx,
        class: ["tiny-milestone__flag", "flag-status-" + flag[_vm.flagStatusField]],
        style: {
          left: "calc(" + 100 / (_vm.data[_vm.flagBefore ? index : index + 1][_vm.flagField].length + 1) * (idx + 1) + "% - 29px)"
        }
      }, [_c("div", {
        staticClass: "tiny-milestone__flag-content",
        style: {
          background: _vm.milestonesStatus[flag[_vm.flagStatusField]]
        },
        on: {
          "mouseleave": function mouseleave($event) {
            return _vm.flagOperate({
              over: false
            });
          },
          "mouseenter": function mouseenter($event) {
            return _vm.flagOperate({
              event: $event,
              text: flag[_vm.flagContentField],
              over: true
            });
          },
          "click": function click($event) {
            return _vm.handleFlagClick({
              idx,
              flag
            });
          }
        }
      }, [_vm._t("flag", function() {
        return [flag[_vm.flagNameField] ? _c("p", [_vm._v(_vm._s(flag[_vm.flagNameField]))]) : _vm._e(), flag[_vm.flagContentField] ? _c("p", {
          staticClass: "content"
        }, [_vm._v(" " + _vm._s(flag[_vm.flagContentField]) + " ")]) : _vm._e()];
      }, {
        "slotScope": flag
      })], 2), _c("div", {
        staticClass: "tiny-milestone__flag-line",
        style: {
          background: _vm.milestonesStatus[flag[_vm.flagStatusField]]
        }
      }, [_c("div", {
        staticClass: "tiny-milestone__dot",
        style: {
          "border-color": _vm.milestonesStatus[flag[_vm.flagStatusField]]
        }
      })])]);
    }), 0) : _vm._e()]), _c("div", {
      staticClass: "tiny-milestone__description"
    }, [_vm._t("bottom", function() {
      return [_c("div", {
        staticClass: "tiny-milestone__description-name"
      }, [_vm._v(" " + _vm._s(node[_vm.nameField]) + " ")]), _c("div", {
        staticClass: "tiny-milestone__description-status"
      }, [_vm._v(" " + _vm._s(node[_vm.timeField]) + " ")])];
    }, {
      "slotScope": node
    })], 2)], 2);
  })], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-milestone-2.22.1.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/milestone/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import Tooltip from '@opentinyvue/vue-tooltip';
import { iconYes } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    Tooltip,
    IconYes: iconYes()
  },
  props: [].concat(props, ["solid", "start", "lineStyle", "timeField", "showNumber", "flagBefore", "completedField", "milestonesStatus", "statusField", "nameField", "flagField", "flagNameField", "flagContentField", "flagStatusField", "data", "space"]),
  emits: ["click", "flagclick", "flag-click"],
  // deprecated 原事件flagclick v3.5.0废弃，v3.17.0移除；移除原因：命名规范
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-milestone"
  }, [_c("tooltip", {
    ref: "tooltip",
    attrs: {
      "type": "normal",
      "placement": "top",
      "content": _vm.state.tipContent
    }
  }), _vm._l(_vm.data, function(node, index) {
    return _c("div", {
      key: index,
      class: ["tiny-milestone__node", {
        "is-solid": _vm.solid
      }, "node-status-" + node[_vm.statusField]],
      style: {
        width: _vm.space ? _vm.space + "px" : 100 / _vm.data.length + "%"
      }
    }, [_vm._t("top", null, {
      "slotScope": node,
      "topSlotClass": "top-slot-class"
    }), _c("div", {
      staticClass: "tiny-milestone__icon tiny-milestone__icon-custom",
      class: [node[_vm.statusField] === _vm.completedField && !_vm.solid ? "is-completed" : "", "status-" + node[_vm.statusField]],
      style: _vm.getMileIcon(node),
      on: {
        "click": function click($event) {
          return _vm.handleClick({
            index,
            node
          });
        }
      }
    }, [_vm._t("icon", function() {
      return [node[_vm.statusField] === _vm.completedField ? _c("icon-yes", {
        staticClass: "tiny-svg-size"
      }) : _c("span", [_vm._v(_vm._s(_vm.showNumber ? index + _vm.start : ""))])];
    }, {
      "slotScope": node
    })], 2), _c("div", {
      class: ["tiny-milestone__line", {
        "tiny-milestone__line-end": index === _vm.data.length - 1,
        "tiny-milestone__line-completed-custom": node[_vm.statusField] === "completed"
      }],
      style: _vm.getLineColor(node[_vm.statusField])
    }, [index < _vm.data.length - 1 ? _c("div", _vm._l(_vm.getMileContent({
      data: _vm.data,
      index
    }), function(flag, idx) {
      return _c("div", {
        key: idx,
        class: ["tiny-milestone__flag", "flag-status-" + flag[_vm.flagStatusField]],
        style: _vm.getFlagStyle({
          index,
          idx
        })
      }, [_c("div", {
        staticClass: "tiny-milestone__flag-content",
        style: {
          background: _vm.milestonesStatus[flag[_vm.flagStatusField]]
        },
        on: {
          "mouseleave": function mouseleave($event) {
            return _vm.flagOperate({
              over: false
            });
          },
          "mouseenter": function mouseenter($event) {
            return _vm.flagOperate({
              event: $event,
              text: flag[_vm.flagContentField],
              over: true
            });
          },
          "click": function click($event) {
            return _vm.handleFlagClick({
              idx,
              flag
            });
          }
        }
      }, [_vm._t("flag", function() {
        return [flag[_vm.flagNameField] ? _c("p", {
          staticClass: "tiny-milestone__flag-name"
        }, [_vm._v(_vm._s(flag[_vm.flagNameField]))]) : _vm._e(), flag[_vm.flagContentField] ? _c("p", {
          staticClass: "tiny-milestone__flag-desc content"
        }, [_vm._v(" " + _vm._s(flag[_vm.flagContentField]) + " ")]) : _vm._e()];
      }, {
        "slotScope": flag
      })], 2), _c("div", {
        staticClass: "tiny-milestone__flag-line",
        style: {
          background: _vm.milestonesStatus[flag[_vm.flagStatusField]]
        }
      }, [_c("div", {
        staticClass: "tiny-milestone__dot",
        style: {
          "border-color": _vm.milestonesStatus[flag[_vm.flagStatusField]]
        }
      })])]);
    }), 0) : _vm._e()]), _c("div", {
      staticClass: "tiny-milestone__description"
    }, [_vm._t("bottom", function() {
      return [_c("div", {
        staticClass: "tiny-milestone__description-name"
      }, [_vm._v(" " + _vm._s(node[_vm.nameField]) + " ")]), _c("div", {
        staticClass: "tiny-milestone__description-status"
      }, [_vm._v(" " + _vm._s(node[_vm.timeField]) + " ")])];
    }, {
      "slotScope": node
    })], 2)], 2);
  })], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
